@@ -7,4 +7,4 @@ def showDatabases():
     return '''sudo mysql -u root -e 'show databases';'''
 
 def exportDatabase(dbName, dbPath):
-    return f'''sudo mysqldump -u root {dbName} > '{dbPath}' --skip-dump-date; '''
\ No newline at end of file
+    return f'''sudo mysqldump -u root {dbName} > '{dbPath}' --skip-dump-date --extended-insert=FALSE;'''
\ No newline at end of file
